import { select, 
        geoPath, 
        zoom, 
        event, 
        geoNaturalEarth1,
       scaleOrdinal,
       schemeSpectral} from 'd3';

import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';

const svg = select('svg');

const projection = geoNaturalEarth1();
const pathGenerator = geoPath().projection(projection);

const g = svg.append('g')
const colorLegendG = svg.append('g')
    .attr('transform', `translate(40,310)`);


const colorScale = scaleOrdinal()
const colorValue = d => d.properties.economy
let selectedColorValue;
let features;
const onClick = d => { selectedColorValue = d 
                     render()};
loadAndProcessData().then(countries => {
  features = countries.features;
  render()
	});
const render = () => {
  colorScale
    .domain(features.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
  	.range(schemeSpectral[colorScale.domain().length])
  
  colorLegendG.call(colorLegend, {
    colorScale,
    circleRadius: 8,
    spacing: 20,
    textOffset: 12,
    backgroundRectWidth: 235,
    onClick,
    selectedColorValue
  });
  
  
g.append('path')
	.attr('class', 'sphere')
	.attr('d', pathGenerator({type: 'Sphere'}))

svg.call(zoom().on('zoom', () =>{
	g.attr('transform', event.transform)
}));
  
  	g.selectAll('path').data(features)
  	.enter()
  	.append('path')
  		.attr('class', 'countries')
  		.attr('title', 'hello')
  		.attr('d', pathGenerator)
   		.attr('fill', d => colorScale(colorValue(d)))
  		.append('title')
  			.text(d => d.properties.name + ': ' + colorValue(d))
  
};